@@ -72,8 +72,11 @@ class FieldsConverter:
             )
 
     def __del__(self):
-        self.db_worker_from.__del__()
-        self.db_worker_to.__del__()
+        try:
+            self.db_worker_from.__del__()
+            self.db_worker_to.__del__()
+        except:
+            pass
 
     @property
     def __str__(self):
